@@ -1,22 +1,25 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import, with_statement
 import os
+
 try:
     from ConfigParser import ConfigParser, DEFAULTSECT
-except ImportError: # python3
+except ImportError:  # python3
     from configparser import ConfigParser, DEFAULTSECT
 
 from .api import select_random
 from .exceptions import PortForException
 
-DEFAULT_CONFIG_PATH = '/etc/port-for.conf'
+
+DEFAULT_CONFIG_PATH = "/etc/port-for.conf"
+
 
 class PortStore(object):
     def __init__(self, config_filename=DEFAULT_CONFIG_PATH):
         self._config = config_filename
 
     def bind_port(self, app, port=None):
-        if '=' in app or ':' in app:
+        if "=" in app or ":" in app:
             raise Exception('invalid app name: "%s"' % app)
 
         if port is not None:
@@ -28,7 +31,10 @@ class PortStore(object):
         if parser.has_option(DEFAULTSECT, app):
             actual_port = parser.get(DEFAULTSECT, app)
             if port is not None and port != actual_port:
-                msg = "Can't bind to port %s: %s is already associated with port %s" % (port, app, actual_port)
+                msg = (
+                    "Can't bind to port %s: %s is already associated "
+                    "with port %s" % (port, app, actual_port)
+                )
                 raise PortForException(msg)
             return int(actual_port)
 
@@ -42,7 +48,9 @@ class PortStore(object):
         if port in app_by_port:
             binding_app = app_by_port[port]
             if binding_app != app:
-                raise PortForException('Port %s is already used by %s!' % (port, binding_app))
+                raise PortForException(
+                    "Port %s is already used by %s!" % (port, binding_app)
+                )
 
         # new app & new port
         parser.set(DEFAULTSECT, app, port)
@@ -56,11 +64,14 @@ class PortStore(object):
         self._save(parser)
 
     def bound_ports(self):
-        return [(app, int(port)) for app, port in self._get_parser().items(DEFAULTSECT)]
+        return [
+            (app, int(port))
+            for app, port in self._get_parser().items(DEFAULTSECT)
+        ]
 
     def _ensure_config_exists(self):
         if not os.path.exists(self._config):
-            with open(self._config, 'wb'):
+            with open(self._config, "wb"):
                 pass
 
     def _get_parser(self):
@@ -70,6 +81,5 @@ class PortStore(object):
         return parser
 
     def _save(self, parser):
-        with open(self._config, 'wt') as f:
+        with open(self._config, "wt") as f:
             parser.write(f)
-
